@@ -14,7 +14,7 @@
 #pyuic4 template_xl.ui -o template_xl.py
 #pyuic4 template_bandpass.ui -o template_bandpass.py
 #pyuic4 arbitStream.ui -o arbitStream.py
-pyuic4 single_col_exp.ui -o single_col_exp.py
+#pyuic4 single_col_exp.ui -o single_col_exp.py
 #pyuic4 controlWidgets.ui -o controlWidgets.py
 #pyuic4 simplePendulum.ui -o simplePendulum.py
 #pyuic4 sensorGrid.ui -o sensorGrid.py
@@ -27,13 +27,15 @@ pyuic4 single_col_exp.ui -o single_col_exp.py
 #
 cd widgets/
 #pyuic4 dial.ui -o dial.py 
+#pyuic4 dialAndDoubleSpin.ui -o dialAndDoubleSpin.py 
+#pyuic4 pulseCounter.ui -o pulseCounter.py 
 #pyuic4 button.ui -o button.py
 #pyuic4 sensorWidget.ui -o sensorWidget.py
 #pyuic4 selectAndButton.ui -o selectAndButton.py
 #pyuic4 spinBox.ui -o spinBox.py
 #pyuic4 doubleSpinBox.ui -o doubleSpinBox.py
 #pyuic4 sineWidget.ui -o sineWidget.py
-#pyuic4 pwmWidget.ui -o pwmWidget.py
+pyuic4 pwmWidget.ui -o pwmWidget.py
 #pyuic4 supplyWidget.ui -o supplyWidget.py
 #pyuic4 setStateList.ui -o setStateList.py
 cd ..
