@@ -9,7 +9,8 @@ sip.setapi("QVariant", 2)
 from PyQt4 import QtCore, QtGui
 import pyqtgraph as pg
 from SEEL_Apps.templates.widgets import dial,button,selectAndButton,sineWidget,pwmWidget,supplyWidget,setStateList,sensorWidget
-from SEEL_Apps.templates.widgets import spinBox,doubleSpinBox
+from SEEL_Apps.templates.widgets import spinBox,doubleSpinBox,dialAndDoubleSpin,pulseCounter
+from SEEL_Apps import saveProfile
 import numpy as np
 
 try:
@@ -29,12 +30,17 @@ class utilitiesClass():
 	plots3D={}
 	plots2D={}
 	axisItems=[]
-	curves=[]
 	total_plot_areas=0
 	funcList=[]
 	gl=None
+	black_trace_colors=[(0,255,20),(255,0,0),(255,255,100),(10,255,255)]
+	white_trace_colors=[(0,255,20),(255,0,0),(255,255,100),(10,255,255)]
+	black_trace_colors+=[QtGui.QColor(random.randint(50,255),random.randint(50,255),random.randint(50,255)) for a in range(50)]
+	white_trace_colors+=[QtGui.QColor(random.randint(50,200),random.randint(50,200),random.randint(50,200)) for a in range(50)]
+	
 	properties={'colorScheme':'black'}
 	def __init__(self):
+		sys.path.append('/usr/share/seelablet')
 		pass
 
 	def __importGL__(self):
@@ -49,30 +55,44 @@ class utilitiesClass():
 
 	def setColorSchemeWhite(self):
 		self.properties['colorScheme']='white'
-		for curve in self.curves:
-			curve.setShadowPen(color=(0,0,0,100), width=3)
 		for plot in self.plots2D:
 			try:
 				plot.setBackground((252,252,245, 255))
-				for a in ['left','bottom','right']:
-					try:
-						axis = plot.getAxis(a)
-						axis.setPen('k')
-					except:
-						pass
 			except:
 				pass
 
+			for a in ['left','bottom','right']:
+				try:
+					axis = plot.getAxis(a)
+					axis.setPen('k')
+				except:
+					pass
+			n=0
+			for c in self.plots2D[plot]: #Change curve colors to match white background
+				c.setPen(color=self.white_trace_colors[n], width=3)
+				n+=1
+				if(n==54):break
+
+
+
 	def setColorSchemeBlack(self):
 		self.properties['colorScheme']='black'
 		for plot in self.plots2D:
-			plot.setBackground((0,0,0,255))
+			try:
+				plot.setBackground((0,0,0,255))
+			except:
+				pass
 			for a in ['left','bottom','right']:
 				try:
 					axis = plot.getAxis(a)
 					axis.setPen('w')
 				except:
 					pass
+				n=0
+				for c in self.plots2D[plot]: #Change curve colors to match black background
+					c.setPen(color=self.black_trace_colors[n], width=3)
+					n+=1
+					if(n==54):break
 
 
 		
@@ -86,6 +106,10 @@ class utilitiesClass():
 		plot=pg.PlotWidget(**args)
 		plot.setMinimumHeight(250)
 		plot_area.addWidget(plot)
+		
+		plot.getAxis('left').setGrid(170)
+		plot.getAxis('bottom').setGrid(170)
+
 		plot.viewBoxes=[]
 		self.plots2D[plot]=[]
 		if self.properties['colorScheme']=='white':
@@ -110,17 +134,26 @@ class utilitiesClass():
 		return plot3d
 
 
-	def addCurve(self,plot,name='',col=(255,255,255),**kwargs):
-		#if(len(name)):curve = plot.plot(name=name)
-		#else:curve = plot.plot()
+	def addCurve(self,plot,name='',**kwargs):
 		if(len(name)):curve = pg.PlotDataItem(name=name)#pg.PlotCurveItem(name=name)
 		else:curve = pg.PlotCurveItem(**kwargs)
 		plot.addItem(curve)
-		curve.setPen(kwargs.get('pen',{'col':(255,255,255),'width':1}))
-		#self.curves.append(curve)
+		if self.properties['colorScheme']=='white':
+			curve.setPen(kwargs.get('pen',{'color':self.white_trace_colors[len(self.plots2D[plot])],'width':1}))
+		elif self.properties['colorScheme']=='black':
+			curve.setPen(kwargs.get('pen',{'color':self.black_trace_colors[len(self.plots2D[plot])],'width':1}))
+		#print (self.black_trace_colors[len(self.plots2D[plot])] , len(self.plots2D[plot]) )
 		self.plots2D[plot].append(curve)
 		return curve
 
+	def removeCurve(self,plot,curve):
+		plot.removeItem(curve)
+		try:
+			self.plots2D[plot].pop(self.plots2D[plot].index(curve))
+		except:
+			pass
+
+
 	def rebuildLegend(self,plot):
 		return plot.addLegend(offset=(-10,30))
 
@@ -311,7 +344,6 @@ class utilitiesClass():
 		def setValue(self,val):
 			retval = self.func(val)
 			if isinstance(retval,numbers.Number):
-				print(retval)
 				self.value.setText('%s'%(self.applySIPrefix(retval*self.scale,self.units) ))
 			else: self.value.setText(str(retval))
 			#self.value.setText('%.2f %s '%(retval*self.scale,self.units))
@@ -320,6 +352,41 @@ class utilitiesClass():
 				#self.linkObj.setText('%.3f %s '%(retval*self.scale,self.units))
 
 
+	class dialAndDoubleSpinIcon(QtGui.QFrame,dialAndDoubleSpin.Ui_Form):
+		def __init__(self,**args):
+			super(utilitiesClass.dialAndDoubleSpinIcon, self).__init__()
+			self.linkFunc = args.get('LINK',None)
+			self.setupUi(self)
+			try:from SEEL.commands_proto import applySIPrefix
+			except ImportError:	self.applySIPrefix = None
+			else:self.applySIPrefix = applySIPrefix
+			self.name = args.get('TITLE','')
+			self.title.setText(self.name)
+			self.func = args.get('FUNC',None)
+			self.units = args.get('UNITS','')
+			self.value.setSuffix(' '+self.units)
+			if 'TOOLTIP' in args:self.widgetFrameOuter.setToolTip(args.get('TOOLTIP',''))
+			self.dial.setMinimum(args.get('MIN',0))
+			self.dial.setMaximum(args.get('MAX',100))
+			self.value.setMinimum(args.get('MIN',0))
+			self.value.setMaximum(args.get('MAX',100))
+
+		def setValue(self,val):
+			retval = self.func(val)
+			self.value.setValue(retval)
+			if self.linkFunc:
+				self.linkFunc(retval,self.units)
+
+		def setDoubleValue(self):
+			try:
+				retval = self.func(self.value.value())
+				self.value.setValue(int(retval))
+				self.dial.setValue(int(retval))
+				if self.linkFunc:
+					self.linkFunc(retval,self.units)
+			except:
+				pass
+
 
 	class buttonIcon(QtGui.QFrame,button.Ui_Form):
 		def __init__(self,**args):
@@ -353,6 +420,7 @@ class utilitiesClass():
 			self.title.setText(self.name)
 			self.func = args.get('FUNC',None)
 			self.units = args.get('UNITS','')
+			self.pushButton.setText(args.get('LABEL','Read'))
 			self.optionBox.addItems(args.get('OPTIONS',[]))
 			if 'TOOLTIP' in args:self.widgetFrameOuter.setToolTip(args.get('TOOLTIP',''))
 
@@ -363,9 +431,27 @@ class utilitiesClass():
 			if isinstance(retval,numbers.Number):self.value.setText('%s'%(self.applySIPrefix(retval,self.units) ))
 			else: self.value.setText(str(retval))
 
+	class pulseCounterIcon(QtGui.QFrame,pulseCounter.Ui_Form):
+		def __init__(self,I):
+			super(utilitiesClass.pulseCounterIcon, self).__init__()
+			self.setupUi(self)
+			self.readfn = I.readPulseCount
+			self.resetfn = I.countPulses
+			self.channelBox.addItems(I.allDigitalChannels)
+
+		def read(self):
+			retval = self.readfn()
+			self.value.setText('%d'%(retval))
+
+		def reset(self):
+			chan = self.channelBox.currentText()
+			if len(chan):self.resetfn(chan)
+
+
+
 	class experimentIcon(QtGui.QPushButton):
 		mouseHover = QtCore.pyqtSignal(str)
-		def __init__(self,basepackage,name,launchfunc):
+		def __init__(self,basepackage,name,launchfunc,*args):
 			super(utilitiesClass.experimentIcon, self).__init__()
 			self.setMouseTracking(True)
 			self.name = name
@@ -373,15 +459,20 @@ class utilitiesClass():
 			genName = tmp.params.get('name',name)
 			self.setText(genName)
 			self.hintText = tmp.params.get('hint','No summary available')
+			try:
+				if 'local' in args: imgloc = pkg_resources.resource_filename(basepackage+'.icons', _fromUtf8(tmp.params.get('image','') )) 
+				else: imgloc = pkg_resources.resource_filename('seel_res.ICONS', _fromUtf8(tmp.params.get('image','') )) 
+			except:
+				imgloc = ''
 			self.hintText = '''
-			<p><strong>%s</strong>.</p>
-			%s
-			'''%(genName.replace('\n',' '), self.hintText)
+			<img src="%s" align="left" width="120" style="margin: 0 20"/><strong>%s</strong><br>%s
+			'''%(imgloc,genName.replace('\n',' '),self.hintText)
 			self.func = launchfunc			
 			self.clicked.connect(self.func)
-			self.setMinimumHeight(70)
 			self.setMaximumWidth(170)
-			self.setStyleSheet("border-image: url(%s) 0 0 0 0 stretch stretch;color:white;"%(pkg_resources.resource_filename(basepackage+'.images', _fromUtf8(tmp.params.get('image','') ))))
+			#self.setStyleSheet("border-image: url(%s) 0 0 0 0 stretch stretch;color:white;"%(pkg_resources.resource_filename('SEEL_Apps.icons', _fromUtf8(tmp.params.get('image','') ))))
+			self.setStyleSheet("color:black;background: qradialgradient(cx: 0.3, cy: -0.4,fx: 0.3, fy: -0.4,radius: 1.35, stop: 0 #fff, stop: 1 #bbb);")
+			self.setMinimumHeight(50)#70)
 
 		def enterEvent(self, event):
 			self.mouseHover.emit(self.hintText)
@@ -389,6 +480,8 @@ class utilitiesClass():
 		def leaveEvent(self, event):
 			self.mouseHover.emit('')
 
+
+
 	class experimentListItem(QtGui.QPushButton):
 		mouseHover = QtCore.pyqtSignal(str)
 		def __init__(self,basepackage,name,launchfunc):
@@ -422,22 +515,23 @@ class utilitiesClass():
 			super(utilitiesClass.sineWidget, self).__init__()
 			self.setupUi(self)
 			self.I = I
+			self.modes = ['sine','tria']
 
 
 		def loadSineTable(self):
 			if self.I:
-				from SEEL.utilityApps import loadSineTable
+				from SEEL_Apps.utilityApps import loadSineTable
 				inst = loadSineTable.AppWindow(self,I=self.I)
 				inst.show()
 			else:
 				print (self.setWindowTitle('Device Not Connected!'))
 
 		def setSINE1(self,val):
-			f=self.I.set_sine1(val)
+			f=self.I.set_w1(val)
 			self.WAVE1_FREQ.setText('%.2f'%(f))
 
 		def setSINE2(self,val):
-			f=self.I.set_sine2(val)
+			f=self.I.set_w2(val)
 			self.WAVE2_FREQ.setText('%.2f'%(f))
 
 		def setSinePhase(self):
@@ -448,6 +542,11 @@ class utilitiesClass():
 			self.WAVE1_FREQ.setText('%.2f'%(f))
 			self.WAVE2_FREQ.setText('%.2f'%(f))
 
+		def setW1Type(self,val):
+			self.I.load_equation('W1',self.modes[val])
+		def setW2Type(self,val):
+			self.I.load_equation('W2',self.modes[val])
+
 
 	class sensorIcon(QtGui.QFrame,sensorWidget.Ui_Form):
 		def __init__(self,cls,**kwargs):
@@ -502,6 +601,16 @@ class utilitiesClass():
 			
 			self.I.sqr4_continuous(self.SQRSF.value(),D1,P2,D2,P3,D3,P4,D4)
 
+
+		def fireSQR1(self):
+			if self.I:
+				from SEEL_Apps.utilityApps import firePulses
+				inst = firePulses.AppWindow(self,I=self.I)
+				inst.show()
+			else:
+				print (self.setWindowTitle('Device Not Connected!'))
+
+
 	class supplyWidget(QtGui.QWidget,supplyWidget.Ui_Form):
 		def __init__(self,I):
 			super(utilitiesClass.supplyWidget, self).__init__()
@@ -543,6 +652,8 @@ class utilitiesClass():
 
 	def saveToCSV(self,table):
 		path = QtGui.QFileDialog.getSaveFileName(self, 'Save File', '~/', 'CSV(*.csv)')
+		sections = path.split('.')
+		if(sections[-1]!='csv'):path+='.csv'
 		if path:
 			import csv
 			with open(unicode(path), 'wb') as stream:
@@ -558,4 +669,40 @@ class utilitiesClass():
 							rowdata.append('')
 					writer.writerow(rowdata)
 
+	def saveDataWindow(self,curveList):
+		from utilityApps import spreadsheet
+		info = spreadsheet.AppWindow(self)
+		colnum=0;labels=[]
+		for a in curveList:
+			x,y = a.getData()
+			name = a.name()
+			if x!=None and y!=None:
+				info.setColumn(colnum,x);colnum+=1
+				info.setColumn(colnum,y);colnum+=1
+				labels.append('%s(X)'%(name));labels.append('%s(Y)'%(name));
+		info.table.setHorizontalHeaderLabels(labels)
+		info.show()
+
+
+	def savePro(self):
+		from os.path import expanduser
+		path = QtGui.QFileDialog.getSaveFileName(self, 'Save Profile',  expanduser("./"), 'INI(*.ini)')
+		sections = path.split('.')
+		if(sections[-1]!='ini'):path+='.ini'
+		if path: saveProfile.guisave(self, QtCore.QSettings(path, QtCore.QSettings.IniFormat))
+
+	def saveSelectedPro(self,parent):
+		from os.path import expanduser
+		path = QtGui.QFileDialog.getSaveFileName(self, 'Save Profile',  expanduser("./"), 'INI(*.ini)')
+		sections = path.split('.')
+		if(sections[-1]!='ini'):path+='.ini'
+		print ('custom save',path)
+		if path: saveProfile.guisave(parent, QtCore.QSettings(path, QtCore.QSettings.IniFormat))
+
+	def loadPro(self):
+		from os.path import expanduser
+		filename = QtGui.QFileDialog.getOpenFileName(self,  "Load a Profile", expanduser("."), 'INI(*.ini)')
+		if filename :
+			saveProfile.guirestore(self, QtCore.QSettings(filename, QtCore.QSettings.IniFormat))
+
 
