@@ -53,6 +53,29 @@ class AppWindow(QtGui.QMainWindow, aboutDevice.Ui_MainWindow):
 			item.setText('%s'%a)
 			ypos+=1
 
+
+	def save(self):  #Save as CSV
+		path = QtGui.QFileDialog.getSaveFileName(self, 'Save File', '~/', 'CSV(*.csv)')
+		if path:
+			import csv
+			with open(unicode(path), 'wb') as stream:
+				headers = []
+				for column in range(self.table.columnCount()):headers.append(self.table.horizontalHeaderItem(column).text())
+				delim = [' ','\t',',',';']
+				writer = csv.writer(stream, delimiter = delim[self.delims.currentIndex()])
+				if self.headerBox.isChecked():writer.writerow(headers)
+				#writer.writeheader()
+				for row in range(self.table.rowCount()):
+					rowdata = []
+					for column in range(self.table.columnCount()):
+						item = self.table.item(row, column)
+						if item is not None:
+							rowdata.append(	unicode(item.text()).encode('utf8'))
+						else:
+							rowdata.append('')
+					writer.writerow(rowdata)
+		
+
 	def __del__(self):
 		print ('bye')
                 
